@@ -31,6 +31,11 @@ class TestEnum : public QObject
 private slots:
     void testEnumCppSignature();
     void testEnumWithApiVersion();
+    void testAnonymousEnum();
+    void testGlobalEnums();
+    void testEnumValueFromNeighbourEnum();
+    void testEnumValueFromExpression();
+    void testPrivateEnum();
 };
 
 #endif
